==> aws-cdk-scala-datasync_2.13-0.1.5-sources.jar: io/burkard/cdk/services/datasync/OptionsProperty.scala <==
package io.burkard.cdk.services.datasync

@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object OptionsProperty {

  def apply(
    bytesPerSecond: Option[Number] = None,
    mtime: Option[String] = None,
    taskQueueing: Option[String] = None,
    verifyMode: Option[String] = None,
    overwriteMode: Option[String] = None,
    atime: Option[String] = None,
    logLevel: Option[String] = None,
    posixPermissions: Option[String] = None,
    gid: Option[String] = None,
    preserveDevices: Option[String] = None,
    securityDescriptorCopyFlags: Option[String] = None,
    preserveDeletedFiles: Option[String] = None,
    uid: Option[String] = None,
    transferMode: Option[String] = None
  ): software.amazon.awscdk.services.datasync.CfnTask.OptionsProperty =
    (new software.amazon.awscdk.services.datasync.CfnTask.OptionsProperty.Builder)
      .bytesPerSecond(bytesPerSecond.orNull)
      .mtime(mtime.orNull)
      .taskQueueing(taskQueueing.orNull)
      .verifyMode(verifyMode.orNull)
      .overwriteMode(overwriteMode.orNull)
      .atime(atime.orNull)
      .logLevel(logLevel.orNull)
      .posixPermissions(posixPermissions.orNull)
      .gid(gid.orNull)
      .preserveDevices(preserveDevices.orNull)
      .securityDescriptorCopyFlags(securityDescriptorCopyFlags.orNull)
      .preserveDeletedFiles(preserveDeletedFiles.orNull)
      .uid(uid.orNull)
      .transferMode(transferMode.orNull)
      .build()
}

==> aws-cdk-scala-datasync_2.13-0.4.1-sources.jar: io/burkard/cdk/services/datasync/OptionsProperty.scala <==
package io.burkard.cdk.services.datasync

@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object OptionsProperty {

  def apply(
    posixPermissions: Option[String] = None,
    gid: Option[String] = None,
    preserveDevices: Option[String] = None,
    bytesPerSecond: Option[Number] = None,
    securityDescriptorCopyFlags: Option[String] = None,
    preserveDeletedFiles: Option[String] = None,
    mtime: Option[String] = None,
    taskQueueing: Option[String] = None,
    verifyMode: Option[String] = None,
    uid: Option[String] = None,
    transferMode: Option[String] = None,
    overwriteMode: Option[String] = None,
    atime: Option[String] = None,
    logLevel: Option[String] = None
  ): software.amazon.awscdk.services.datasync.CfnTask.OptionsProperty =
    (new software.amazon.awscdk.services.datasync.CfnTask.OptionsProperty.Builder)
      .posixPermissions(posixPermissions.orNull)
      .gid(gid.orNull)
      .preserveDevices(preserveDevices.orNull)
      .bytesPerSecond(bytesPerSecond.orNull)
      .securityDescriptorCopyFlags(securityDescriptorCopyFlags.orNull)
      .preserveDeletedFiles(preserveDeletedFiles.orNull)
      .mtime(mtime.orNull)
      .taskQueueing(taskQueueing.orNull)
      .verifyMode(verifyMode.orNull)
      .uid(uid.orNull)
      .transferMode(transferMode.orNull)
      .overwriteMode(overwriteMode.orNull)
      .atime(atime.orNull)
      .logLevel(logLevel.orNull)
      .build()
}
